@@ -54,7 +54,7 @@ use constant REASON => 'Perl::MinimumVersion::Reason';
 
 use vars qw{$VERSION @ISA @EXPORT_OK %CHECKS %MATCHES};
 BEGIN {
-	$VERSION = '1.25';
+	$VERSION = '1.26';
 
 	# Only needed for dev releases, comment out otherwise
 	$VERSION = eval $VERSION;
@@ -65,6 +65,10 @@ BEGIN {
 
 	# The primary list of version checks
 	%CHECKS = (
+		_feature_bundle_5_12    => version->new('5.012'),
+		_yada_yada_yada         => version->new('5.012'),
+		_pkg_name_version       => version->new('5.012'),
+
 		_perl_5010_pragmas      => version->new('5.010'),
 		_perl_5010_operators    => version->new('5.010'),
 		_perl_5010_magic        => version->new('5.010'),
@@ -505,10 +509,41 @@ sub version_markers {
 
 
 
-
 #####################################################################
 # Version Check Methods
 
+sub _yada_yada_yada {
+	shift->Document->find_first( sub {
+		$_[1]->isa('PPI::Token::Operator')
+		and $_[1]->content eq '...'
+	} );
+}
+
+sub _feature_bundle_5_12 {
+	shift->Document->find_first( sub {
+		$_[1]->isa('PPI::Statement::Include') or return '';
+		$_[1]->pragma eq 'feature'            or return '';
+		my @child = $_[1]->schildren;
+		my @args = @child[1..$#child]; # skip 'use', 'feature' and ';'
+		foreach my $arg (@args) {
+			return $arg->content if $arg->content =~ /:5\.12/;
+		}
+		return '';
+	} );
+}
+
+sub _pkg_name_version {
+	shift->Document->find_first( sub {
+		$_[1]->isa('PPI::Statement::Package') or return '';
+		my @child = $_[1]->schildren();
+		$child[0]->isa('PPI::Token::Word')    or return '';
+		$child[0]->content eq 'package'       or return '';
+		$child[1]->isa('PPI::Token::Word')    or return '';
+		$child[2]->isa('PPI::Token::Number')  or return '';
+		return 1;
+	} );
+}
+
 sub _perl_5010_pragmas {
 	shift->Document->find_first( sub {
 		$_[1]->isa('PPI::Statement::Include')
@@ -970,6 +1005,9 @@ B<Write the explicit version checker>
 
 B<Write the recursive module descend stuff>
 
+B<Check for more 5.12 features (currently only detecting
+C<package NAME VERSION;>, C<...>, and C<use feature ':5.12'>)>
+
 =head1 SUPPORT
 
 All bugs should be filed via the CPAN bug tracker at
